import React, { useState, useRef } from 'react';
import { Modal, Button, message, Popconfirm, Typography } from 'antd';
import { PageContainer, FooterToolbar } from '@ant-design/pro-layout';
import { PlusOutlined } from '@ant-design/icons';
import ProTable from '@ant-design/pro-table';
const { Paragraph, Text } = Typography;

import { PageAuthorization, AddAuthorization, UpdateAuthorization } from "./services"
const App = () => {

    const actionRef = useRef();
    const [ModalVisible, handleModalVisible] = useState(false);
    const [currentRow, setCurrentRow] = useState();
    const columns = [
        {
            title: '主键',
            dataIndex: 'id',
            hideInSearch: true,
            hideInTable: true,
            tip: '规则名称是唯一的 key'
        },
        {
            title: 'TenantId',
            dataIndex: 'groupId',
            valueType: 'textarea',
            search: false,
            render: (text) => <Paragraph style={{ display: 'inline' }} copyable>{text}</Paragraph>,
        },
        {
            title: '授权码',
            dataIndex: 'key',
            valueType: 'textarea',
            search: false,
            render: (text) => <Paragraph style={{ display: 'inline' }} copyable>{text}</Paragraph>,
        },
        {
            title: '操作',
            dataIndex: 'option',
            valueType: 'option',
            fixed: 'right',
            width: 450,
            render: (_, record) => [
                <Popconfirm
                    type="primary"
                    key="primary"
                    title="确认更新吗?"
                    okText="是"
                    cancelText="否"
                    onConfirm={() => {
                        UpdateAuthorization(record.id).then((r) => {
                            if (r.statusCode == 200 && r.data) {
                                actionRef.current.reload();
                                message.success("修改成功");
                            } else {
                                message.error(r.errors || "修改失败");
                            }
                        });
                    }}
                    onCancel={() => { }}
                >
                    <a href="#">更新</a>
                </Popconfirm>,

            ],
        },
    ];

    return (
        <PageContainer host header={{ title: '', breadcrumb: {}, }}>
            <ProTable
                actionRef={actionRef}
                rowKey="id"
                pagination={{ defaultPageSize: 10 }}
                search={{
                    labelWidth: 120,
                }}
                toolBarRender={() => [
                    <Button
                        type="primary"
                        key="primary"
                        onClick={() => {
                            AddAuthorization().then((r) => {
                                if (r.statusCode == 200 && r.data) {
                                    message.success("添加成功");
                                    actionRef.current.reload();
                                } else {
                                    message.error(r.errors || "添加失败");
                                }
                            });
                        }} >
                        <PlusOutlined /> 添加授权码
                    </Button>,
                ]}
                request={async (params) => {
                    var data = [];
                    var total = 0;
                    await PageAuthorization(params).then((r) => {
                        total = r.data.total;
                        data = r.data.data;
                    });
                    return {
                        data: data,
                        success: true,
                        total: total,
                    };
                }}
                columns={columns}
            />

        </PageContainer>
    );
};

export default App;
